@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '0.34';
+  $CPAN::Perl::Releases::VERSION = '0.36';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -228,6 +228,10 @@ our $data =
     "tar.bz2" => "S/ST/STEVAN/perl-5.15.3.tar.bz2",
     "tar.gz" => "S/ST/STEVAN/perl-5.15.3.tar.gz",
   },
+  "5.15.4" => {
+    "tar.bz2" => "F/FL/FLORA/perl-5.15.4.tar.bz2",
+    "tar.gz" => "F/FL/FLORA/perl-5.15.4.tar.gz",
+  },
   "5.6.0" => {
     "tar.gz" => "G/GS/GSAR/perl-5.6.0.tar.gz",
   },
@@ -336,7 +340,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 0.34
+version 0.36
 
 =head1 SYNOPSIS
 
